==> acquia_dam-1.0.1.tar.gz: acquia_dam/tests/src/Functional/AcquiaDamConfigurationFormTest.php <==
<?php

namespace Drupal\Tests\acquia_dam\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test Acquia Dam settings from.
 *
 * @group acquia_dam
 */
class AcquiaDamConfigurationFormTest extends BrowserTestBase {

  /**
   * Path to settings form.
   */
  const DAM_SETTINGS_FORM_PATH = '/admin/config/acquia-dam';

  /**
   * User that has admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Unauthorized user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $unAuthorizedUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'acquia_dam',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);

    $this->unAuthorizedUser = $this->drupalCreateUser();
  }

  /**
   * Test permission of different users.
   *
   * @throws \Behat\Mink\Exception\ExpectationException
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testFormAccess():void {
    $this->drupalLogin($this->adminUser);
    $session = $this->assertSession();

    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $session->pageTextContains('Acquia DAM Configuration');
    $session->statusCodeEquals(200);

    $this->drupalLogout();
    $this->drupalLogin($this->unAuthorizedUser);

    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $session->pageTextContains('Access denied');
    $session->statusCodeEquals(403);
  }

  /**
   * Test form input of the domain.
   */
  public function testFormDomainField():void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'eudaimonia.widencollective.com'], 'Save DAM configuration');
    $this->assertTrue($this->config('acquia_dam.settings')->get('domain') == 'eudaimonia.widencollective.com');
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'https://eudaimonia.widencollective.com/'], 'Save DAM configuration');
    $this->assertTrue($this->config('acquia_dam.settings')->get('domain') == 'eudaimonia.widencollective.com');
  }

  /**
   * Test correct redirection of the domain field.
   */
  public function testRedirectionDomainField():void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'eudaimonia.widencollective.com'], 'Save DAM configuration');
    $url = $this->getSession()->getCurrentUrl();
    $host = parse_url($url, PHP_URL_HOST);
    $this->assertEquals($this->config('acquia_dam.settings')->get('domain'), $host);
  }

}

==> acquia_dam-1.0.3.tar.gz: acquia_dam/tests/src/Functional/AcquiaDamConfigurationFormTest.php <==
<?php

namespace Drupal\Tests\acquia_dam\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test Acquia Dam settings from.
 *
 * @group acquia_dam
 */
class AcquiaDamConfigurationFormTest extends BrowserTestBase {

  /**
   * Path to settings form.
   */
  const DAM_SETTINGS_FORM_PATH = '/admin/config/acquia-dam';

  /**
   * User that has admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Unauthorized user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $unAuthorizedUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'acquia_dam',
    'acquia_dam_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);

    $this->unAuthorizedUser = $this->drupalCreateUser();
  }

  /**
   * Test permission of different users.
   *
   * @throws \Behat\Mink\Exception\ExpectationException
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testFormAccess():void {
    $this->drupalLogin($this->adminUser);
    $session = $this->assertSession();

    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $session->pageTextContains('Acquia DAM Configuration');
    $session->statusCodeEquals(200);

    $this->drupalLogout();
    $this->drupalLogin($this->unAuthorizedUser);

    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $session->pageTextContains('Access denied');
    $session->statusCodeEquals(403);
  }

  /**
   * Test form input of the domain.
   */
  public function testFormDomainField():void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'test.widencollective.connect'], 'Save DAM configuration');
    $this->assertTrue($this->config('acquia_dam.settings')->get('domain') == 'test.widencollective.connect');
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'https:/test.widencollective.connect/'], 'Save DAM configuration');
    $this->assertTrue($this->config('acquia_dam.settings')->get('domain') == 'test.widencollective.connect');
  }

  /**
   * Test correct redirection of the domain field.
   */
  public function testRedirectionDomainField():void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet(self::DAM_SETTINGS_FORM_PATH);
    $this->submitForm(['domain' => 'test.widencollective.connect'], 'Save DAM configuration');
    $url = $this->getSession()->getCurrentUrl();
    $host = parse_url($url, PHP_URL_HOST);
    $this->assertEquals($this->config('acquia_dam.settings')->get('domain'), $host);
  }

}
